================
Modules
================


.. highlight:: shell

----------------
Dataset
----------------

.. automodule:: octis.dataset.dataset
    :members:

------------------------
Data Preprocessing
------------------------

.. automodule:: octis.preprocessing.preprocessing
    :members:

------------------------
Evaluation Measures
------------------------

.. automodule:: octis.evaluation_metrics.metrics
    :members:


.. automodule:: octis.evaluation_metrics.coherence_metrics
    :members:

.. automodule:: octis.evaluation_metrics.diversity_metrics
    :members:

.. automodule:: octis.evaluation_metrics.classification_metrics
    :members:

.. automodule:: octis.evaluation_metrics.topic_significance_metrics
    :members:
------------------------
Optimization
------------------------

.. automodule:: octis.optimization.optimizer
    :members:

.. automodule:: octis.optimization.optimizer_tool
    :members:


------------------------
Models
------------------------

.. automodule:: octis.models.model
    :members:

.. automodule:: octis.models.LDA
    :members:

.. automodule:: octis.models.NFM
    :members:

.. automodule:: octis.models.NMF_scikit
    :members:

.. automodule:: octis.models.CTM
    :members:

.. automodule:: octis.models.ETM
    :members:
